@@ -89,7 +89,7 @@ class CacheStorage(ProfileStorage):
             if rep.is_like(url, branch):
                 return rep
         else:
-            return ProfileRepository.clone(url, self, branch)
+            return ProfileRepository.clone(url, self, branch or DEFAULT_BRANCH)
 
 class RepositoryStorageSet(RepositoryStorageInterface):
     """
@@ -120,6 +120,10 @@ class RepositoryStorageSet(RepositoryStorageInterface):
         for rep in self:
             if rep.is_like(url, branch):
                 return rep
+        for storage in self.storages:
+            rep = storage.get_repository(url, branch)
+            if rep:
+                return rep
         return None
 
     def is_local(self, url, branch=DEFAULT_BRANCH):
